@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2021 Thomas Perl <m@thp.io>
+# Copyright (c) 2008-2022 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -66,6 +66,7 @@ DEFAULT_CONFIG = {
         'new': True,
         'error': True,
         'unchanged': False,
+        'empty-diff': True,
     },
 
     'report': {
@@ -142,6 +143,7 @@ DEFAULT_CONFIG = {
         'discord': {
             'enabled': False,
             'embed': False,
+            'colored': True,
             'subject': '{count} changes: {jobs}',
             'webhook_url': '',
             'max_message_length': 2000,
@@ -534,7 +536,7 @@ class CacheMiniDBStorage(CacheStorage):
         if dirname and not os.path.isdir(dirname):
             os.makedirs(dirname)
 
-        self.db = minidb.Store(self.filename, debug=True)
+        self.db = minidb.Store(self.filename, debug=True, vacuum_on_close=False)
         self.db.register(CacheEntry)
 
     def close(self):
@@ -585,6 +587,7 @@ class CacheMiniDBStorage(CacheStorage):
         if keep_id is not None:
             result = CacheEntry.delete_where(self.db, (CacheEntry.c.guid == guid) & (CacheEntry.c.id != keep_id))
             self.db.commit()
+            self.db.vacuum()
             return result
 
         return 0
